<div align="center"> 

![](https://forge.steffo.eu/steffo/emblematic/raw/branch/main/.media/icon-128x128_round.png) 

# Emblematic

Generate emblems from an icon and a background

</div>

## Quick setup

Make sure [pipx] and [Inkscape] are installed, then:

```bash
pipx install emblematic
pipx run emblematic --version
pipx run emblematic --help
```

See [the documentation] for more information.

[pipx]: https://pipx.pypa.io/latest/
[Inkscape]: https://inkscape.org/
[the documentation]: https://artifacts.steffo.eu/steffo/emblematic/latest/docs/

## Links

### Tools

<a href="https://www.python.org/">
    <img alt="Written in Python" title="Written in Python" src="https://img.shields.io/badge/language-python-3775a9" height="30px">
</a>
&hairsp;
<a href="https://www.sphinx-doc.org/en/master/">
    <img alt="Prose with Sphinx" title="Prose with Sphinx" src="https://img.shields.io/badge/prose-sphinx-0a507a" height="30px">
</a>
&hairsp;
<a href="https://docs.pytest.org/en/stable/">
    <img alt="Testing with pytest" title="Testing with pytest" src="https://img.shields.io/badge/testing-pytest-00a0e4" height="30px">
</a>
&hairsp;
<a href="https://inkscape.org">
    <img alt="SVG conversion with Inkscape" title="SVG conversion with Inkscape" src="https://img.shields.io/badge/svg%20conversion-inkscape-06263f" height="30px">
</a>

### Packaging

<a href="https://pypi.org/project/emblematic">
    <img alt="Available on PyPI" title="Available on PyPI" src="https://img.shields.io/pypi/v/emblematic?label=pypi&color=ffd242" height="30px">
</a>
&hairsp;
<a href="https://forge.steffo.eu/steffo/-/packages/pypi/emblematic">
    <img alt="Available on Forgejo Packages" title="Available on Forgejo Packages" src="https://img.shields.io/badge/forgejo%20packages-latest-ff6600" height="30px">
</a>

### Documentation

<a href="https://artifacts.steffo.eu/steffo/emblematic/">
    <img alt="Documentation available" title="Documentation available" src="https://img.shields.io/website?url=https%3A%2F%2Fartifacts.steffo.eu%2Fsteffo%2Femblematic%2F&up_color=175d36&up_message=available&down_message=error&label=documentation" height="30px">
</a>
&hairsp;
<a href="https://interoperable-europe.ec.europa.eu/collection/eupl/eupl-text-eupl-12">
    <img alt="Licensed under EUPL-1.2" title="Licensed under EUPL-1.2" src="https://img.shields.io/badge/license-eupl--1.2-003399" height="30px">
</a>


### Development

<a href="https://forge.steffo.eu/steffo/emblematic">
    <img alt="Code repository" title="Code repository" src="https://img.shields.io/gitea/last-commit/steffo/emblematic?gitea_url=https%3A%2F%2Fforge.steffo.eu&color=374351" height="30px">
</a>
&hairsp;
<a href="https://forge.steffo.eu/steffo/emblematic/releases">
    <img alt="Releases" title="Releases" src="https://img.shields.io/gitea/v/release/steffo/emblematic?gitea_url=https%3A%2F%2Fforge.steffo.eu&label=last+release&color=374351" height="30px">
</a>
&hairsp;
<a href="https://forge.steffo.eu/steffo/emblematic/issues">
    <img alt="Issues" title="Issues" src="https://img.shields.io/gitea/issues/open/steffo/emblematic?gitea_url=https%3A%2F%2Fforge.steffo.eu&label=issues&color=374351" height="30px">
</a>
&hairsp;
<a href="https://forge.steffo.eu/steffo/emblematic/issues">
    <img alt="Pull requests" title="Issues" src="https://img.shields.io/gitea/pull-requests/open/steffo/emblematic?gitea_url=https%3A%2F%2Fforge.steffo.eu&color=374351" height="30px">
</a>
